pub enum Error {
Unexpected(Error),
User(Error),
Help {
command: Vec<String>,
output: String,
code: i32,
},
IoError(Error),
Config(Error),
ExitWithCode(i32),
}Expand description
A top level error type for ffx tool results
Variants
Unexpected(Error)
An error that qualifies as a bugcheck
User(Error)
A known kind of error that can be reported usefully to the user
Help
An early-exit that should result in outputting help to the user (like argh::EarlyExit),
but is not itself an error in any meaningful sense.
Fields
IoError(Error)
An error from general I/O. Meant mostly to handle things like write!() and such, but also for potential issues with piping outputs of other commands into ffx. This isn’t something that’s exactly common, but is a possibility.
Config(Error)
Something failed before ffx’s configuration could be loaded (like an invalid argument, a failure to read an env config file, etc).
Errors of this type should include any information the user might need to recover from the issue, because it will not advise the user to look in the log files or anything like that.
ExitWithCode(i32)
Exit with a specific error code but no output
Implementations